/// <reference types="node" />
import { FinishedProcess } from "./finished-process";
import { KilledProcess } from "./killed-process";
import * as scanner from "./scanner";
/** a long-running process whose behavior can be observed at runtime */
export declare class RunningProcess {
    /** the underlying ChildProcess instance */
    private childProcess;
    /** populated when the process finishes */
    private result;
    /** the STDIN stream of the underlying ChildProcess */
    stdin: NodeJS.WritableStream;
    /** searchable STDOUT stream of the underlying ChildProcess */
    stdout: scanner.Stream;
    /** searchable STDERR stream of the underlying ChildProcess */
    stderr: scanner.Stream;
    /** searchable combined STDOUT and STDERR stream */
    output: scanner.Stream;
    /** functions to call when this process ends  */
    private endedCallbacks;
    constructor(args: {
        cwd: string;
        env: NodeJS.ProcessEnv;
        params: string[];
        runnable: string;
    });
    /** stops the currently running process */
    kill(): Promise<KilledProcess>;
    /** returns the process ID of the underlying ChildProcess */
    pid(): number;
    /** returns a promise that resolves when the underlying ChildProcess terminates */
    waitForEnd(): Promise<FinishedProcess | KilledProcess>;
    /**
     * Called when the underlying ChildProcess ends.
     * This gets called for natural ends and kills.
     */
    private onClose;
}
